package com.zipcode.io;
import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;

import java.rmi.server.ExportException;
import java.util.Arrays;
import java.util.Scanner;

public class AccountApp {

    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";

    private Dao<Account, Integer> accountDao;

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "1");
            // setup our  DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            // processData();
            crudLoop();
            System.out.println("\n\nIt seems to have worked\n\n");
        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    private void crudLoop() throws Exception {
        boolean flag = true;
        while(flag) {
            System.out.println("Enter a [c][r][u][d] command: ");
            Scanner scanner = new Scanner(System.in);
            String action = scanner.nextLine();

            if (action.equals("c")) {
                System.out.println("Name :");
                String name = scanner.nextLine();
                System.out.println("Password :");
                String password = scanner.nextLine();

                createData(name, password);
            }

            if (action.equals("r")) {
                readData();
            }

            if (action.equals("u")) {
                System.out.println("Id :");
                int id = Integer.parseInt(scanner.nextLine());
                System.out.println("New Name :");
                String name = scanner.nextLine();
                System.out.println("New Password :");
                String password = scanner.nextLine();

                updateData(id, name, password);
            }

            if (action.equals("d")) {
                System.out.println("Id :");
                int id = Integer.parseInt(scanner.nextLine());

                deleteData(id);
            }

            if (action.equals("exit")) {
                System.out.println("Bye");
                flag = false;
            }
        }
    }

    private void createData(String name, String password) throws Exception {
        Account account = new Account(name, password);

        accountDao.create(account);
        int id = account.getId();
        System.out.println(id);
        accountDao.update(account);
    }

    private void updateData(int id, String name, String password) throws Exception {
        Account account = accountDao.queryForId(id);

        account.setName(name);
        account.setPassword(password);
        accountDao.update(account);
    }

    private void readData() throws Exception {
        for (Account a : accountDao.queryForAll()) {
            System.out.println(a.toString());
        }
    }

    private void deleteData(int id) throws Exception {
        accountDao.deleteById(id);
    }

    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }
}
